@@ -7,7 +7,7 @@ BEGIN
 use strict;
 use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS %CherokeeClasses %CherokeeEquivalence $pseudoMatrix);
 
-	$VERSION = "0.02";
+	$VERSION = "0.03";
 	
 	@EXPORT_OK = qw(%CherokeeClasses %CherokeeEquivalence &getForm &setForm &subForm &formatForms);
 	%EXPORT_TAGS = ( utils => [qw(&getForm &setForm &subForm &formatForms)] );
@@ -24,7 +24,7 @@ use vars qw($VERSION @EXPORT_OK %EXPORT_TAGS %CherokeeClasses %CherokeeEquivalen
 	Ꭶ	=> "Ꭶ-Ꭼ",
 	Ꭽ	=> "Ꭽ-Ꮂ",
 	Ꮃ	=> "Ꮃ-Ꮈ",
-	Ꮉ	=> "Ꮉ-Ꮍ ",
+	Ꮉ	=> "Ꮉ-Ꮍ",
 	Ꮎ	=> "Ꮎ-Ꮕ",
 	Ꮖ	=> "Ꮖ-Ꮛ",
 	Ꮜ	=> "Ꮜ-Ꮢ",
@@ -285,9 +285,9 @@ $_ = ($#_) ? $_[1] : $_[0];
 	# is used in place of \p{Cherokee}, dangerous...
 	#
 	# s/(\p{Cherokee})\{%([\d,-]+)\}/setRange($1,$2)/eog;
-	s/(\w)\{%([\d,-]+)\}/setRange($1,$2)/eog;
+	s/(\w)\{#([\d,-]+)#\}/setRange($1,$2)/eog;
 
-	s/\[(\^)?(\p{Cherokee}+.*?)\]\{(\^)?%([\d,-]+)\}/setRange($2,$4,$1,$3)/eog;
+	s/\[(\^)?(\p{Cherokee}+.*?)\]\{(\^)?#([\d,-]+)#\}/setRange($2,$4,$1,$3)/eog;
 
 	$_;
 }
